==> cryptide-1.5.1.tgz: package/src/c25519Point.js <==
// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

/** @typedef {import('./ecPointBase').BNInput} BNInput */

import EcPointBase from './ecPointBase';
import EcCurve from './ecCurve';
import elliptic from 'elliptic';
const curve = EcCurve.custom25519();

export default class C25519Point extends EcPointBase {
    static get infinity() { return new C25519Point(); }
    static get p() { return curve.pCasted; }
    static get n() { return curve.nCasted; }
    static get g() { return new C25519Point(curve.g); }

    get _curve() { return curve; }
    
    /**
     * @param {BNInput|elliptic.curve.base.BasePoint} x
     * @param {BNInput} y
     */
    constructor(x = null, y = null) {
        super(x, y);
    }

    /**
     * @param {Uint8Array} data
     * @returns {C25519Point}
     */
    static from(data, compact = false) {
        return Object.setPrototypeOf(super._from(curve, data, compact), C25519Point.prototype);
    }

    /**
     * @param {string} message
     * @returns {C25519Point}
     */
    static fromString(message) {
        return Object.setPrototypeOf(super._fromString(curve, message), C25519Point.prototype);
    }
}

==> cryptide-2.1.0.tgz: package/src/c25519Point.js <==
// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

import EcPointBase from './ecPointBase';
import EcCurve from './ecCurve';
import elliptic from 'elliptic';
const curve = EcCurve.custom25519();

export default class C25519Point extends EcPointBase {
    static get infinity() { return new C25519Point(); }
    static get p() { return curve.pCasted; }
    static get n() { return curve.nCasted; }
    static get g() { return new C25519Point(curve.g); }

    get _curve() { return curve; }
    
    /**
     * @param {import('./bnInput').BNInput|elliptic.curve.base.BasePoint} x
     * @param {import('./bnInput').BNInput} y
     */
    constructor(x = null, y = null) {
        super(x, y);
    }

    /**
     * @param {Uint8Array} data
     * @returns {C25519Point}
     */
    static from(data, compact = false) {
        return Object.setPrototypeOf(super._from(curve, data, compact), C25519Point.prototype);
    }

    /**
     * @param {string} message
     * @returns {C25519Point}
     */
    static fromString(message) {
        return Object.setPrototypeOf(super._fromString(curve, message), C25519Point.prototype);
    }
}
